aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core/SkShader.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/core/SkShader.h')
-rw-r--r--include/core/SkShader.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/core/SkShader.h b/include/core/SkShader.h
index a0a1b056d4..23e095029b 100644
--- a/include/core/SkShader.h
+++ b/include/core/SkShader.h
@@ -18,7 +18,7 @@
class SkPath;
class GrContext;
-class GrCustomStage;
+class GrEffect;
class GrSamplerState;
/** \class SkShader
@@ -306,11 +306,11 @@ public:
virtual GradientType asAGradient(GradientInfo* info) const;
/**
* If the shader subclass has a GrCustomStage implementation, this installs
* a custom stage on the sampler. A GrContext pointer is required since custom
* stages may need to create textures. The sampler parameter is necessary to set a
* texture matrix. It will eventually be removed and this function will operate as a
- * GrCustomStage factory.
+ * GrEffect factory.
*/
virtual bool asNewCustomStage(GrContext* context, GrSamplerState* sampler) const;
@@ -306,11 +306,11 @@ public:
virtual GradientType asAGradient(GradientInfo* info) const;
/**
- * If the shader subclass has a GrCustomStage implementation, this installs
+ * If the shader subclass has a GrEffect implementation, this installs
* a custom stage on the sampler. A GrContext pointer is required since custom
* stages may need to create textures. The sampler parameter is necessary to set a